==> leonardo-0.4.1.tgz: leonardo-0.4.1/lib/providers/css.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from web_resource import TopLevelResource, FileObjectResource



class CSSProvider:
    
    
    def __init__(self, lfs, config):
        self.lfs    = lfs
        self.config = config
        
        self.css_id = config.css_id
        
        
    def get(self, resource_id, request, main_resource):
        if resource_id == self.css_id:
            return CSSResource(self.lfs, self.config)
        else:
            return None



class CSSResource(FileObjectResource, TopLevelResource):


    def __init__(self, lfs, config):
        css_id = config.css_id
        TopLevelResource.__init__(self, css_id, "text/css")
        FileObjectResource.__init__(self, lfs.get(css_id, "css"))


    def is_read_only(self):
        return False # allow editing

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/providers/css.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from web_resource import TopLevelResource, FileObjectResource



class CSSProvider:
    
    
    def __init__(self, lfs, config):
        self.lfs    = lfs
        self.config = config
        
        self.css_id = config.css_id
        
        
    def get(self, resource_id, request, main_resource):
        if resource_id == self.css_id:
            return CSSResource(self.lfs, self.config)
        else:
            return None



class CSSResource(FileObjectResource, TopLevelResource):


    def __init__(self, lfs, config):
        css_id = config.css_id
        TopLevelResource.__init__(self, css_id, "text/css")
        FileObjectResource.__init__(self, lfs.get(css_id))


    def is_read_only(self):
        return False # allow editing


    def get_content_type(self):
        return "css"
